@@ -1,7 +1,7 @@
 /*
   This file is part of KAddressBook.
 
-  Copyright (c) 2016 Laurent Montel <montel@kde.org>
+  Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ class ContactTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit ContactTest(QObject *parent = Q_NULLPTR);
+    explicit ContactTest(QObject *parent = nullptr);
     ~ContactTest();
 private Q_SLOTS:
     void shouldHaveDefaultValue();
